@@ -8,12 +8,18 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.assertions._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_lambda._jsii
 import aws_cdk.cloud_assembly_schema._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
+import aws_cdk.cx_api._jsii
+import aws_cdk.triggers._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/integ-tests", "1.153.0", __name__[0:-6], "integ-tests@1.153.0.jsii.tgz"
+    "@aws-cdk/integ-tests", "1.155.0", __name__[0:-6], "integ-tests@1.155.0.jsii.tgz"
 )
 
 __all__ = [
